@@ -1,3 +1,5 @@
+use std::future::Future;
+use std::pin::Pin;
 use serde_json::{Value as Json};
 use crate::table::Table;
 #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
@@ -22,7 +24,7 @@ use crate::collectors::row::Row;
 /// assert_eq!(Order::table_name(), "orders");
 /// ```
 #[async_trait::async_trait]
-pub trait ArelAble: Sized {
+pub trait ArelAble: Sized + Send + Sync {
     type PersistedRowRecord;
 
     fn id() -> &'static str { Self::primary_key() }
@@ -96,6 +98,23 @@ pub trait ArelAble: Sized {
         Self::query().fetch_count_with_executor(executor).await
     }
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn fetch_self_with_executor<'c, E>(&self, executor: E) -> anyhow::Result<Self> where E: sqlx::Executor<'c, Database=sqlx::Any> {
+        let primary_key = Self::primary_key();
+        let attr_primary_key = Self::table_column_name_to_attr_name(Self::primary_key())?;
+        if let Some(attr_primary_key_json) = self.persisted_attr_json(attr_primary_key) {
+            let mut map = serde_json::Map::new();
+            map.insert(primary_key.to_string(), attr_primary_key_json);
+            Self::query().r#where(serde_json::Value::Object(map)).fetch_one_with_executor(executor).await
+        } else {
+            Err(anyhow::anyhow!("model not persisted"))
+        }
+    }
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn fetch_self(&self) -> anyhow::Result<Self> {
+        let db_state = crate::visitors::get_db_state()?;
+        self.fetch_self_with_executor(db_state.pool()).await
+    }
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn fetch_count() -> anyhow::Result<i64> { Self::query().fetch_count().await }
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn save_with_executor<'c, E>(&mut self, executor: E) -> anyhow::Result<()> where E: sqlx::Executor<'c, Database=sqlx::Any>;
@@ -106,8 +125,50 @@ pub trait ArelAble: Sized {
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn delete(&mut self) -> anyhow::Result<sqlx::any::AnyQueryResult>;
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
-    async fn with_transaction() -> anyhow::Result<()> {
-        let db_state = crate::visitors::get_db_state()?;
-        db_state.transaction().await
+    fn with_transaction<'s, F: Send + 's>(callback: F) -> Pin<Box<dyn Future<Output = anyhow::Result<()>> + Send + 's>>
+        where for<'c> F: FnOnce(&'c mut sqlx::Transaction<sqlx::Any>) -> Pin<Box<dyn Future<Output = anyhow::Result<()>> + Send + 'c >>
+    {
+        Box::pin(async move {
+            let db_state = crate::visitors::get_db_state()?;
+            db_state.with_transaction(callback).await
+        })
     }
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    fn with_lock<'s, F: Send + 'static>(&'s self, callback: F) -> Pin<Box<dyn Future<Output = anyhow::Result<()>> + Send + 's>>
+        where for<'c>
+              F: FnOnce(&'c mut sqlx::Transaction<sqlx::Any>) -> Pin<Box<dyn Future<Output = anyhow::Result<()>> + Send + 'c >>
+    {
+        Box::pin(async move {
+            let primary_key = Self::primary_key();
+            let attr_primary_key = Self::table_column_name_to_attr_name(Self::primary_key())?;
+            if let Some(attr_primary_key_json) = self.persisted_attr_json(attr_primary_key) {
+                let mut map = serde_json::Map::new();
+                map.insert(primary_key.to_string(), attr_primary_key_json);
+                Self::with_transaction(|tx| Box::pin(async move {
+                    Self::lock().r#where(serde_json::Value::Object(map)).limit(1).execute_with_executor(&mut *tx).await?;
+                    callback(&mut *tx).await
+                })).await
+            } else {
+                Err(anyhow::anyhow!("model not persisted"))
+            }
+        })
+    }
+    // async fn with_lock<F: Send + 'static>(&self, callback: F) -> anyhow::Result<()>
+    //     where for<'c>
+    //           F: FnOnce(&'c mut sqlx::Transaction<sqlx::Any>) -> Pin<Box<dyn Future<Output = anyhow::Result<()>> + Send + 'c >>,
+    //           Self: Send
+    // {
+    //     let primary_key = Self::primary_key();
+    //     let attr_primary_key = Self::table_column_name_to_attr_name(Self::primary_key())?;
+    //     if let Some(attr_primary_key_json) = self.persisted_attr_json(attr_primary_key) {
+    //         let mut map = serde_json::Map::new();
+    //         map.insert(primary_key.to_string(), attr_primary_key_json);
+    //         Self::with_transaction(|tx| Box::pin(async move {
+    //             Self::lock().r#where(serde_json::Value::Object(map)).limit(1).execute_with_executor(&mut *tx).await?;
+    //             callback(&mut *tx).await
+    //         })).await
+    //     } else {
+    //         Err(anyhow::anyhow!("model not persisted"))
+    //     }
+    // }
 }
\ No newline at end of file
